/*
* ASIX PRESTO DLL library interface
* distributed as-is, without any warranties
* https://www.asix.tech/
*
* version 1.1, April 2022
* 
*/

#include "presto.h"

HINSTANCE hDLL; /* Handle to DLL */

LPFNDLLQOpenPresto            QOpenPresto;
LPFNDLLQClosePresto           QClosePresto;
LPFNDLLQSetPins               QSetPins;
LPFNDLLQGetPins               QGetPins;
LPFNDLLQPoweronVdd            QPoweronVdd;
LPFNDLLQPoweroffVdd           QPoweroffVdd;
LPFNDLLQDelay                 QDelay;
LPFNDLLQSetActiveLED          QSetActiveLED;
LPFNDLLAGet                   AGet;
LPFNDLLAGetBlocking           AGetBlocking;
LPFNDLLAClearFatalError       AClearFatalError;
LPFNDLLQShiftByte             QShiftByte;
LPFNDLLQShiftByte_OutIn       QShiftByte_OutIn;
LPFNDLLQCheckSupplyVoltage    QCheckSupplyVoltage;
LPFNDLLQPoweronVpp13V         QPoweronVpp13V;
LPFNDLLQPoweroffVpp13V        QPoweroffVpp13V;
LPFNDLLQSetDPullup            QSetDPullup;
LPFNDLLQCheckGoButton         QCheckGoButton;
LPFNDLLQSetPrestoSpeed        QSetPrestoSpeed;
LPFNDLLAGetProgList           AGetProgList;


int LoadPrestoDll(char* filename)
{
    int ok = 1;
    hDLL = LoadLibraryA(filename);
    if (hDLL != NULL) {
    
        QOpenPresto = (LPFNDLLQOpenPresto)GetProcAddress(hDLL, "QOpenPresto");
        QClosePresto = (LPFNDLLQClosePresto)GetProcAddress(hDLL, "QClosePresto");
        QSetPins = (LPFNDLLQSetPins)GetProcAddress(hDLL, "QSetPins");     
        QGetPins = (LPFNDLLQGetPins)GetProcAddress(hDLL, "QGetPins"); 
        QPoweronVdd = (LPFNDLLQPoweronVdd)GetProcAddress(hDLL, "QPoweronVdd");
        QPoweroffVdd = (LPFNDLLQPoweroffVdd)GetProcAddress(hDLL, "QPoweroffVdd");
        QDelay = (LPFNDLLQDelay)GetProcAddress(hDLL, "QDelay");                                      
        QSetActiveLED = (LPFNDLLQSetActiveLED)GetProcAddress(hDLL, "QSetActiveLED");    
        AGet = (LPFNDLLAGet)GetProcAddress(hDLL, "AGet");
        AGetBlocking = (LPFNDLLAGetBlocking)GetProcAddress(hDLL, "AGetBlocking");      
        AClearFatalError = (LPFNDLLAClearFatalError)GetProcAddress(hDLL, "AClearFatalError");
        QShiftByte = (LPFNDLLQShiftByte)GetProcAddress(hDLL, "QShiftByte");
        QShiftByte_OutIn = (LPFNDLLQShiftByte_OutIn)GetProcAddress(hDLL, "QShiftByte_OutIn");
        QCheckSupplyVoltage = (LPFNDLLQCheckSupplyVoltage)GetProcAddress(hDLL, "QCheckSupplyVoltage");
        QPoweronVpp13V = (LPFNDLLQPoweronVpp13V)GetProcAddress(hDLL, "QPoweronVpp13V");
        QPoweroffVpp13V = (LPFNDLLQPoweroffVpp13V)GetProcAddress(hDLL, "QPoweroffVpp13V");
        QSetDPullup = (LPFNDLLQSetDPullup)GetProcAddress(hDLL, "QSetDPullup");
        QCheckGoButton = (LPFNDLLQCheckGoButton)GetProcAddress(hDLL, "QCheckGoButton");
        QSetPrestoSpeed = (LPFNDLLQSetPrestoSpeed)GetProcAddress(hDLL, "QSetPrestoSpeed");
        AGetProgList = (LPFNDLLAGetProgList)GetProcAddress(hDLL, "AGetProgList");        
           

        if (!QOpenPresto) ok = 0;     
        if (!QClosePresto) ok = 0;
        if (!QSetPins) ok = 0;
        if (!QGetPins) ok = 0;
        if (!QPoweronVdd) ok = 0;
        if (!QPoweroffVdd) ok = 0;
        if (!QDelay) ok = 0;
        if (!QSetActiveLED) ok = 0;
        if (!AGet) ok = 0;
        if (!AGetBlocking) ok = 0;
        if (!AClearFatalError) ok = 0; 
        if (!QShiftByte) ok = 0;
        if (!QShiftByte_OutIn) ok = 0;
        if (!QCheckSupplyVoltage) ok = 0;
        if (!QPoweronVpp13V) ok = 0;
        if (!QPoweroffVpp13V) ok = 0;
        if (!QSetDPullup) ok = 0;
        if (!QCheckGoButton) ok = 0;
        if (!QSetPrestoSpeed) ok = 0;
        if (!AGetProgList) ok = 0;        
        if (ok == 0) {
            FreeLibrary(hDLL);
            return PRESTO_DLL_LOAD_FAIL_FUNCTION;
        }
        else {
            return PRESTO_DLL_LOAD_OK;
        }
    }
    else {
        return PRESTO_DLL_LOAD_FAIL_NAME;
    }
}





