/*
* This file is C wrapper for ASIX PRESTO programmer DLL
* distributed as-is, without any warranties
* https://www.asix.tech/
*
* version 1.1, April 2022
* 
*/

#ifndef _PRESTO_H_
#define _PRESTO_H_

#include <windows.h>

/* QSetPins constants */
#define PINS_HI     0x03
#define PINS_LO     0x02
#define PINS_HIZ    0x01
#define PINS_D_BIT  0x00
#define PINS_C_BIT  0x02
#define PINS_P_BIT  0x04
#define PINS_L_BIT  0x06

/* QShift... constants */
#define SHIFT_OUTIN_PIND  0x00 
#define SHIFT_OUTIN_PINL  0x01
#define SHIFT_OUTIN_PINP  0x02
#define SHIFT_OUTIN_PINI  0x03
#define SHIFT_MODE1       0x01 
#define SHIFT_MODE3       0x03

/* QSetPrestoSpeed constants */
#define PRESTO_CLK1   0x00 // 3MHz - default value
#define PRESTO_CLK2   0x01 // 1.5MHz
#define PRESTO_CLK4   0x02 // 750kHz
#define PRESTO_CLK32  0x03 // 93.75kHz

/* DLL loading */
#define PRESTO_DLL_LOAD_OK               0
#define PRESTO_DLL_LOAD_FAIL_NAME        1
#define PRESTO_DLL_LOAD_FAIL_FUNCTION    2

int LoadPrestoDll(char* filename);


/* DLL exported functions */
typedef void (CALLBACK* LPFNDLLQOpenPresto)(int sn);
typedef void (CALLBACK* LPFNDLLQClosePresto)(void);
typedef void (CALLBACK* LPFNDLLQSetPins)(int pins);
typedef void (CALLBACK* LPFNDLLQGetPins)(void);
typedef void (CALLBACK* LPFNDLLQPoweronVdd)(int delayus);
typedef void (CALLBACK* LPFNDLLQPoweroffVdd)(void);
typedef void (CALLBACK* LPFNDLLQDelay)(int delayus);
typedef void (CALLBACK* LPFNDLLQSetActiveLED)(int led);
typedef int  (CALLBACK* LPFNDLLAGet)(int *answer);
typedef int  (CALLBACK* LPFNDLLAGetBlocking)(void);
typedef void (CALLBACK* LPFNDLLAClearFatalError)(void);
typedef void (CALLBACK* LPFNDLLQShiftByte)(int databyte, int mode);
typedef void (CALLBACK* LPFNDLLQShiftByte_OutIn)(int databyte, int mode, int InputPin);
typedef void (CALLBACK* LPFNDLLQCheckSupplyVoltage)(void);
typedef void (CALLBACK* LPFNDLLQPoweronVpp13V)(void);
typedef void (CALLBACK* LPFNDLLQPoweroffVpp13V)(void);
typedef void (CALLBACK* LPFNDLLQSetDPullup)(int dpullup_on);
typedef void (CALLBACK* LPFNDLLQCheckGoButton)(void);
typedef void (CALLBACK* LPFNDLLQSetPrestoSpeed)(int speed);
typedef void (CALLBACK* LPFNDLLAGetProgList)(int *sn_list, int count, int *count_returned);


LPFNDLLQOpenPresto            QOpenPresto;
LPFNDLLQClosePresto           QClosePresto;
LPFNDLLQSetPins               QSetPins;
LPFNDLLQGetPins               QGetPins;
LPFNDLLQPoweronVdd            QPoweronVdd;
LPFNDLLQPoweroffVdd           QPoweroffVdd;
LPFNDLLQDelay                 QDelay;
LPFNDLLQSetActiveLED          QSetActiveLED;
LPFNDLLAGet                   AGet;
LPFNDLLAGetBlocking           AGetBlocking;
LPFNDLLAClearFatalError       AClearFatalError;
LPFNDLLQShiftByte             QShiftByte;
LPFNDLLQShiftByte_OutIn       QShiftByte_OutIn;
LPFNDLLQCheckSupplyVoltage    QCheckSupplyVoltage;
LPFNDLLQPoweronVpp13V         QPoweronVpp13V;
LPFNDLLQPoweroffVpp13V        QPoweroffVpp13V;
LPFNDLLQSetDPullup            QSetDPullup;
LPFNDLLQCheckGoButton         QCheckGoButton;
LPFNDLLQSetPrestoSpeed        QSetPrestoSpeed;
LPFNDLLAGetProgList           AGetProgList;

#endif /* _PRESTO_H_ */

